{ config, pkgs, ... }:
{
  imports =
    [
      ./hardware-configuration.nix
      ../../modules/home-manager.nix
      ../../modules/nur-and-unstable.nix
      ../../modules/base.nix
      ../../modules/base-efi.nix
      ../../modules/power-management.nix
      ../../modules/tuxedo-rs.nix
      ../../modules/ntfs.nix
      ../../modules/git.nix
      ../../modules/zsh.nix
      ../../modules/nitrokey-gpg-smartcard.nix
      ../../modules/ssh-client.nix
      ../../modules/ssh-server.nix
      ../../modules/lid-switch-handling.nix

      ../../modules/btrfs-scrub.nix
      ../../modules/btrfs-mount-options.nix

      ../../modules/gpu-amd.nix
      #../../modules/kde.nix
      ../../modules/gnome-base.nix
      ../../modules/gnome-config.nix
      ../../modules/gnome-extensions.nix
      ../../modules/gnome-fractional-scaling.nix
      ../../modules/fwupd-gnome.nix
      ../../modules/gnome-wallpaper.nix

      #../../modules/gnome-terminal.nix
      ../../modules/blackbox.nix

      ../../modules/programs-base.nix
      ../../modules/programs.nix
      ../../modules/flatpak.nix
      ../../modules/ausweisapp.nix
      ../../modules/nextcloud-client.nix
      ../../modules/syncthing.nix
      ../../modules/signal-desktop.nix
      ../../modules/obsidian.nix
      ../../modules/vlc-dvd-blu-ray.nix
      ../../modules/firefox.nix
      ../../modules/thunderbird.nix
      ../../modules/tor-browser.nix
      ../../modules/digikam-rawtherapee-hugin-gimp.nix
      ../../modules/freetube.nix
      ../../modules/ghostwriter.nix
      ../../modules/print-and-scan.nix
      #../../modules/waydroid.nix
      ../../modules/games.nix

      ../../modules/autostart.nix

      ../../modules/boxes.nix
      #../../modules/virtualbox.nix
      ../../modules/jetbrains-ide.nix
      #../../modules/vscodium.nix
      ../../modules/android.nix
      ../../modules/pmbootstrap.nix

      #../../modules/podman.nix
      ../../modules/docker.nix
      ../../modules/docker-pushrm.nix
    ];

  networking.hostName = "yodaTux";
  boot.initrd.luks.devices."luks-ea7099e3-320d-4eb3-a4c3-9910a9af817b".allowDiscards = true;
  yoda.btrfsFileSystems = ["/"];
  #yoda.btrfsMounts = yoda.btrfsFileSystems;

  # Systemd Journal entry:
  # S Sat Sep 23 16:11:52 2023 p4 kernel: TSC found unstable after boot, most likely due to broken BIOS. Use 'tsc=unstable'.
  boot.kernelParams = [ "tsc=unstable" ];

  # List all available kernel versions:
  #   `nix repl` -> `:l <nixpkgs>` -> `pkgs.linuxPackages` and press `TAB`
  # Default.
  #boot.kernelPackages = pkgs.linuxPackages;
  # Latest.
  boot.kernelPackages = pkgs.linuxPackages_latest;
  # Hardened.
  # https://archlinux.org/packages/extra/x86_64/linux-hardened/
  # -> https://github.com/anthraxx/linux-hardened
  #boot.kernelPackages = pkgs.linuxPackages_hardened;
  # Free/Libre.
  # https://en.wikipedia.org/wiki/Linux-libre
  #boot.kernelPackages = pkgs.linuxPackages-libre;

  # Most users should never change this value after the initial install, for any reason, even if you’ve upgraded your system to a new NixOS release.
  system.stateVersion = "23.05";
}
